<?php

/**
 * @file
 * Contains \Drupal\publish_away\Plugin\Field\FieldWidget\PublishAwayTwitterWidget.
 */

namespace Drupal\publish_away\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;

/**
 * Plugin implementation of the 'publish_away_twitter_default' widget.
 *
 * @FieldWidget(
 *   id = "publish_away_twitter_widget",
 *   label = @Translation("on Twitter"),
 *   field_types = {
 *     "publish_away_twitter",
 *   },
 *   settings = {
 *     "rows" = "4",
 *     "grouptitle" = "Publish away on Twitter",
 *     "maxlength" = "115", 
 *     "placeholder" = "",
 *     "progress_indicator" = "throbber",
 *     "preview_image_style" = "thumbnail",
 *   }
 * )
 */
class PublishAwayTwitterWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, array &$form_state) {
    $element['grouptitle'] = array(
      '#type' => 'textfield',
      '#title' => t('Title of fieldset'),
      '#default_value' => $this->getSetting('grouptitle'),
    );
    $element['maxlength'] = array(
      '#type' => 'number',
      '#title' => t('Max length of textarea'),
      '#default_value' => $this->getSetting('maxlength'),
      '#required' => TRUE,
      '#disabled' => TRUE,
      '#min' => 1,
    );
    // TextareaWidget.
    $element['rows'] = array(
      '#type' => 'number',
      '#title' => t('Rows'),
      '#default_value' => $this->getSetting('rows'),
      '#required' => TRUE,
      '#disabled' => TRUE,
      '#min' => 1,
    );
    $element['placeholder'] = array(
      '#type' => 'textfield',
      '#title' => t('Placeholder'),
      '#default_value' => $this->getSetting('placeholder'),
      '#description' => t('Text that will be shown inside the field until a value is entered. This hint is usually a sample value or a brief description of the expected format.'),
    );
    // FileWidget.
    $element['progress_indicator'] = array(
      '#type' => 'radios',
      '#title' => t('Progress indicator'),
      '#options' => array(
        'throbber' => t('Throbber'),
        'bar' => t('Bar with progress meter'),
      ),
      '#default_value' => $this->getSetting('progress_indicator'),
      '#description' => t('The throbber display does not show the status of uploads but takes up less space. The progress bar is helpful for monitoring progress on large uploads.'),
      '#weight' => 16,
      '#access' => file_progress_implementation(),
    );
    // ImageWidget.
    $element['preview_image_style'] = array(
      '#title' => t('Preview image style'),
      '#type' => 'select',
      '#options' => image_style_options(FALSE),
      '#empty_option' => '<' . t('no preview') . '>',
      '#default_value' => $this->getSetting('preview_image_style'),
      '#description' => t('The preview image will be shown while editing the content.'),
      '#weight' => 15,
    );
    return $element;
  }
  
  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = array();
    $settings = $this->getSettings();
    if (!empty($settings)) {
      foreach ($settings as $key => $value) {
        if (trim($value) === '') {
          continue;
        }
        $summary[] = t(ucfirst($key). ': @' . $key, array('@' . $key => $value));
      }
    }
    else {
      $summary[] = t('No placeholder');
    }

    return $summary;
  }


  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, array &$form_state) {
    $element['enabled'] = array(
      '#type' => 'checkbox',
      '#prefix' => '<fieldset><legend>'.$this->getSetting('grouptitle').'</legend>',  
      '#title' => t('Enable sending on the current save.'),
      '#default_value' => (int) FALSE,
      // '#default_value' => isset($items[$delta]->enabled) ? $items[$delta]->enabled : NULL,
      '#description' => t("This option is explicitly disabled by default regardless of content's state."), 
    );
    $element['message'] = array(
      '#type' => 'textarea',
      '#title' => t('Message for Twitter'),
      '#rows' => $this->getSetting('rows'),
      '#maxlength' => $this->getSetting('maxlength'),
      '#default_value' => isset($items[$delta]->message) ? $items[$delta]->message : '',
      '#description' => t('The message to be displayed on Twitter. The maximum is @maxlength characters.', 
              array('@maxlength' => $this->getSetting('maxlength'))),
      '#placeholder' => $this->getSetting('placeholder'),
      '#attributes' => array('class' => array('text-full')),  
    );
    $element['file_fid'] = array(
      '#title' => t('Image for Twitter'),
      '#type' => 'managed_file',
      '#theme' => 'file_widget',
      '#required' => TRUE,
      '#preview_image_style' => $this->getSetting('preview_image_style'),  
      '#upload_validators' => array("file_validate_extensions" => array("png gif jpg jpeg")),
      '#upload_location' => 'public://publish_away',
      '#progress_indicator' => $this->getSetting('progress_indicator'),  
      '#description' => t('Allowed extensions: png gif jpg jpeg'),
      '#suffix' => '</fieldset>',
    );
    if (isset($items[$delta]->file_fid) && !empty($items[$delta]->file_fid)) {
      $element['file_fid'] += array('#default_value' => array($items[$delta]->file_fid));
    }

    return $element;
  }

}
